Constructor

Trait Constructor 

pub trait Constructor<In, Out> {
    // Required method
    fn construct(self, input: In) -> Out;
}
Marker trait for types that can turn a list of values into something else.

This is used for on_ok() methods so the provided closures can take each recorded value as separate argument instead of deconstructing tuples.

There are default implementations for FnMut closures with up to 10 arguments.

Required Methods

fn construct(self, input: In) -> Out

Take the input and convert it into output.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, Out, Func> Constructor<(A, B, C, D, E, F, G, H, I, J, K, L), Out> for Func
where Func: FnMut(A, B, C, D, E, F, G, H, I, J, K, L) -> Out,

Source

impl<A, B, C, D, E, F, G, H, I, J, K, Out, Func> Constructor<(A, B, C, D, E, F, G, H, I, J, K), Out> for Func
where Func: FnMut(A, B, C, D, E, F, G, H, I, J, K) -> Out,

Source

impl<A, B, C, D, E, F, G, H, I, J, Out, Func> Constructor<(A, B, C, D, E, F, G, H, I, J), Out> for Func
where Func: FnMut(A, B, C, D, E, F, G, H, I, J) -> Out,

Source

impl<A, B, C, D, E, F, G, H, I, Out, Func> Constructor<(A, B, C, D, E, F, G, H, I), Out> for Func
where Func: FnMut(A, B, C, D, E, F, G, H, I) -> Out,

Source

impl<A, B, C, D, E, F, G, H, Out, Func> Constructor<(A, B, C, D, E, F, G, H), Out> for Func
where Func: FnMut(A, B, C, D, E, F, G, H) -> Out,

Source

impl<A, B, C, D, E, F, G, Out, Func> Constructor<(A, B, C, D, E, F, G), Out> for Func
where Func: FnMut(A, B, C, D, E, F, G) -> Out,

Source

impl<A, B, C, D, E, F, Out, Func> Constructor<(A, B, C, D, E, F), Out> for Func
where Func: FnMut(A, B, C, D, E, F) -> Out,

Source

impl<A, B, C, D, E, Out, Func> Constructor<(A, B, C, D, E), Out> for Func
where Func: FnMut(A, B, C, D, E) -> Out,

Source

impl<A, B, C, D, Out, Func> Constructor<(A, B, C, D), Out> for Func
where Func: FnMut(A, B, C, D) -> Out,

Source

impl<A, B, C, Out, Func> Constructor<(A, B, C), Out> for Func
where Func: FnMut(A, B, C) -> Out,

Source

impl<A, B, Out, Func> Constructor<(A, B), Out> for Func
where Func: FnMut(A, B) -> Out,

Source

impl<A, Out, F> Constructor<(A,), Out> for F
where F: FnMut(A) -> Out,

Source

impl<Out, F> Constructor<(), Out> for F
where F: FnMut() -> Out,