pub trait Constructor<In, Out> {
// Required method
fn construct(self, input: In) -> Out;
}Expand description
Marker trait for types that can turn a list of values into something else.
This is used for on_ok() methods so the provided closures can take each
recorded value as separate argument instead of deconstructing tuples.
There are default implementations for FnMut closures with up to 10
arguments.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".